References to BioServices on the Web
===========================================


* Galaxy: See the Log Archive at `Galaxy log archive <http://wiki.galaxyproject.org/Community/Log/2013/UsingBioServicesWithGalaxy>`_
* EBI: See `EBI programming web services <http://www.ebi.ac.uk/Tools/webservices/tutorials/06_programming/python>`_
* WikiPathways: `references <http://wikipathways.tumblr.com/search/bioservices>`_
* GeneProf: `example python <https://www.geneprof.org/GeneProf/webapi.jsp#example-python>`_
* http://www.scoop.it/t/bioinformatique
* http://bioinfo-fr.net/bioservices-module-python
*  http://devbio.eu/?p=resources&presel=bioinfo
* biomartian from Endre Bakken Stovner https://github.com/endrebak/biomartian
